itkwasm.pipeline - itkwasm python documentation
Description: Module Contents: Classes:,, Pipeline, Run an itk-wasm WASI pipeline.,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.pipeline`

## Module Contents

### Classes

`Pipeline` | Run an itk-wasm WASI pipeline.

### API

class itkwasm.pipeline.Pipeline(pipeline: Union[str, pathlib.Path, bytes])

  Run an itk-wasm WASI pipeline.

  Initialization

  Compile the pipeline.

  run(args: List[str], outputs: List[itkwasm.pipeline_output.PipelineOutput] = [], inputs: List[itkwasm.pipeline_input.PipelineInput] = []) → Tuple[itkwasm.pipeline_output.PipelineOutput]

    Run the itk-wasm pipeline.

  _wasmtime_lift(ptr: int, size: int)
  _wasmtime_lower(ptr: int, data: Union[bytes, bytearray])
  _set_input_array(data_array: Union[bytes, bytearray], input_index: int, sub_index: int) → int
  _set_input_json(data_object: Dict, input_index: int) → None
  _get_output_json(output_index: int) → Dict